==> open_watcom_1.4.0-src.zip: bld/clib/mthread/c/regdata.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Thread data size registration. Allows the caller to override
*               the default. Used by the C++ runtime.
*
****************************************************************************/


#include "variety.h"
#include "thread.h"
#include "trdlist.h"

extern void     (*_AccessTDList)(void);
extern void     (*_ReleaseTDList)(void);

extern _WCRTLINK unsigned __ThreadDataSize;

_WCRTLINK unsigned __RegisterThreadDataSize( unsigned size )
/*********************************************************/
{
    unsigned    offset;

    _AccessTDList();
    offset = __ThreadDataSize;
    __ThreadDataSize += size;
    #if !defined(__UNIX__) && !defined(_NETWARE_CLIB)
        __ResizeThreadDataList();
    #endif
    _ReleaseTDList();
    return( offset );
}

==> open_watcom_1.7.0-src.zip: bld/clib/mthread/c/regdata.c <==
/****************************************************************************
*
*                            Open Watcom Project
*
*    Portions Copyright (c) 1983-2002 Sybase, Inc. All Rights Reserved.
*
*  ========================================================================
*
*    This file contains Original Code and/or Modifications of Original
*    Code as defined in and that are subject to the Sybase Open Watcom
*    Public License version 1.0 (the 'License'). You may not use this file
*    except in compliance with the License. BY USING THIS FILE YOU AGREE TO
*    ALL TERMS AND CONDITIONS OF THE LICENSE. A copy of the License is
*    provided with the Original Code and Modifications, and is also
*    available at www.sybase.com/developer/opensource.
*
*    The Original Code and all software distributed under the License are
*    distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
*    EXPRESS OR IMPLIED, AND SYBASE AND ALL CONTRIBUTORS HEREBY DISCLAIM
*    ALL SUCH WARRANTIES, INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF
*    MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR
*    NON-INFRINGEMENT. Please see the License for the specific language
*    governing rights and limitations under the License.
*
*  ========================================================================
*
* Description:  Thread data size registration. Allows the caller to override
*               the default. Used by the C++ runtime.
*
****************************************************************************/


#include "variety.h"
#include "thread.h"
#include "trdlist.h"

extern void     (*_AccessTDList)(void);
extern void     (*_ReleaseTDList)(void);

_WCRTDATA extern unsigned   __ThreadDataSize;

_WCRTLINK unsigned __RegisterThreadDataSize( unsigned size )
/**********************************************************/
{
    unsigned    offset;

    _AccessTDList();
    offset = __ThreadDataSize;
    __ThreadDataSize += size;
#if !defined(__UNIX__) && !defined(_NETWARE_CLIB)
    __ResizeThreadDataList();
#endif
    _ReleaseTDList();
    return( offset );
}
